@@ -71,24 +71,27 @@ class CustomSensor(CBPiSensor):
 
         self.value_old = 9999
         # defines how ofte a large delta can be rejected
-        self.max_counter = 1
+        self.max_counter = 2
         # counts subsequent rejected values
         self.counter = 0
 
 
         self.max = max31865.max31865(self.csPin,self.misoPin, self.mosiPin, self.clkPin, self.ResSens, self.RefRest, int(self.ConfigReg,16))
-               
+            
+    def read(self):
+        # get current Unit setting for temperature (Sensor needs to be saved again or system restarted for now)
+        self.TEMP_UNIT=self.get_config_value("TEMP_UNIT", "C")
+        temp = self.max.readTemp()
+        if self.TEMP_UNIT == "C": # Report temp in C if nothing else is selected in settings
+            temp = round((temp + self.offset),2)
+        else: # Report temp in F if unit selected in settings
+            temp = round((9.0 / 5.0 * temp + 32 + self.offset), 2)
+        return temp
+
     async def run(self):
 
         while self.running == True:
-            # get current Unit setting for temperature (Sensor needs to be saved again or system restarted for now)
-            self.TEMP_UNIT=self.get_config_value("TEMP_UNIT", "C")
-            self.temp = self.max.readTemp()
-            if self.TEMP_UNIT == "C": # Report temp in C if nothing else is selected in settings
-                self.temp = round((self.temp + self.offset),2)
-            else: # Report temp in F if unit selected in settings
-                self.temp = round((9.0 / 5.0 * self.temp + 32 + self.offset), 2)
-
+            self.temp = self.read()
             if self.value_old == 9999:
                 self.value_old = self.temp
 
@@ -103,7 +106,8 @@ class CustomSensor(CBPiSensor):
                 self.push_update(self.value)
             # active delta filter
             else:
-                if abs(self.temp-self.value_old) < self.delta_filter:
+                delta = abs(self.temp-self.value_old)
+                if delta < self.delta_filter:
                     self.value = round((self.temp * self.alpha + self.value_old * ( 1 - self.alpha)),2)
                     self.log_data(self.value)
                     self.push_update(self.value)
